==> core_models-0.1.0.gem: app/controllers/core_models/misc/vat_rates_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Misc::VatRatesController < CoreModelsController
    # GET /misc/vat_rates
    # GET /misc/vat_rates.json
    def index
      @misc_vat_rates = Misc::VatRate.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @misc_vat_rates }
      end
    end

    # GET /misc/vat_rates/1
    # GET /misc/vat_rates/1.json
    def show
      @misc_vat_rate = Misc::VatRate.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @misc_vat_rate }
      end
    end

    # GET /misc/vat_rates/new
    # GET /misc/vat_rates/new.json
    def new
      @misc_vat_rate = Misc::VatRate.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @misc_vat_rate }
      end
    end

    # GET /misc/vat_rates/1/edit
    def edit
      @misc_vat_rate = Misc::VatRate.find(params[:id])
    end

    # POST /misc/vat_rates
    # POST /misc/vat_rates.json
    def create
      @misc_vat_rate = Misc::VatRate.new(params[:misc_vat_rate])

      respond_to do |format|
        if @misc_vat_rate.save
          format.html { redirect_to @misc_vat_rate, :notice => 'Vat rate was successfully created.' }
          format.json { render :json => @misc_vat_rate, :status => :created, :location => @misc_vat_rate }
        else
          format.html { render :action => "new" }
          format.json { render :json => @misc_vat_rate.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /misc/vat_rates/1
    # PUT /misc/vat_rates/1.json
    def update
      @misc_vat_rate = Misc::VatRate.find(params[:id])

      respond_to do |format|
        if @misc_vat_rate.update_attributes(params[:misc_vat_rate])
          format.html { redirect_to @misc_vat_rate, :notice => 'Vat rate was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @misc_vat_rate.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /misc/vat_rates/1
    # DELETE /misc/vat_rates/1.json
    def destroy
      @misc_vat_rate = Misc::VatRate.find(params[:id])
      @misc_vat_rate.destroy

      respond_to do |format|
        format.html { redirect_to misc_vat_rates_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/misc/vat_rates_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Misc::VatRatesController < CoreModelsController
    # GET /misc/vat_rates
    # GET /misc/vat_rates.json
    def index
      @misc_vat_rates = Misc::VatRate.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @misc_vat_rates }
      end
    end

    # GET /misc/vat_rates/1
    # GET /misc/vat_rates/1.json
    def show
      @misc_vat_rate = Misc::VatRate.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @misc_vat_rate }
      end
    end

    # GET /misc/vat_rates/new
    # GET /misc/vat_rates/new.json
    def new
      @misc_vat_rate = Misc::VatRate.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @misc_vat_rate }
      end
    end

    # GET /misc/vat_rates/1/edit
    def edit
      @misc_vat_rate = Misc::VatRate.find(params[:id])
    end

    # POST /misc/vat_rates
    # POST /misc/vat_rates.json
    def create
      @misc_vat_rate = Misc::VatRate.new(params[:misc_vat_rate])

      respond_to do |format|
        if @misc_vat_rate.save
          format.html { redirect_to @misc_vat_rate, :notice => 'Vat rate was successfully created.' }
          format.json { render :json => @misc_vat_rate, :status => :created, :location => @misc_vat_rate }
        else
          format.html { render :action => "new" }
          format.json { render :json => @misc_vat_rate.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /misc/vat_rates/1
    # PUT /misc/vat_rates/1.json
    def update
      @misc_vat_rate = Misc::VatRate.find(params[:id])

      respond_to do |format|
        if @misc_vat_rate.update(params[:misc_vat_rate])
          format.html { redirect_to @misc_vat_rate, :notice => 'Vat rate was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @misc_vat_rate.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /misc/vat_rates/1
    # DELETE /misc/vat_rates/1.json
    def destroy
      @misc_vat_rate = Misc::VatRate.find(params[:id])
      @misc_vat_rate.destroy

      respond_to do |format|
        format.html { redirect_to misc_vat_rates_url }
        format.json { head :no_content }
      end
    end
  end
end
